User Guide — QuadratiK 1.0.0 documentation

Skip to main content
`Ctrl`+`K`

# User Guide

## Dataset

- Wireless Indoor Localization Dataset
  - Format
  - Details
  - Source
  - References

## Usage Examples

- QuadratiK Usage Examples
  - Normality Test
    - Parametric
    - Non-parametric
    - QQ Plot
  - Two Sample Test
  - K-Sample Test
  - Poisson Kernel Test
    - QQ Plot
  - Poisson Kernel based Clustering
    - Elbow Plot using Euclidean Distance and Cosine Similarity based WCSS
  - Density Estimation and Sample Generation from PKBD
  - Tuning Parameter \(h\) selection